==> hvcg_identity_openapi_identity-0.0.1.crate: hvcg_identity_openapi_identity-0.0.1/docs/mutation_user_api.md <==
# mutation_user_api

All URIs are relative to *http://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**deactive-user**](mutation_user_api.md#deactive-user) | **PUT** /mutation-api/user/deactive/{id} | Deactive user
**update-password**](mutation_user_api.md#update-password) | **PUT** /mutation-api/user/update-password/{id} | update password
**update-user-info**](mutation_user_api.md#update-user-info) | **PUT** /mutation-api/user/update-info/{id} | Deactive user


# **deactive-user**
> models::User deactive-user(ctx, id)
Deactive user

Deactive user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| The user id | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update-password**
> models::User update-password(ctx, id, inline_object)
update password

Update user password

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| The user id | 
  **inline_object** | [**InlineObject**](InlineObject.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update-user-info**
> models::User update-user-info(ctx, id, user)
Deactive user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| The user id | 
  **user** | [**User**](User.md)| User object that needs to be added to the database | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> hvcg_identity_openapi_identity-0.1.1.crate: hvcg_identity_openapi_identity-0.1.1/docs/mutation_user_api.md <==
# mutation_user_api

All URIs are relative to *http://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**activate_user**](mutation_user_api.md#activate_user) | **POST** /mutation-api/users/activation | Activate a user
**deactivate_user**](mutation_user_api.md#deactivate_user) | **POST** /mutation-api/users/deactivation | Deactive user
**update-password**](mutation_user_api.md#update-password) | **PUT** /mutation-api/users/password | update password


# **activate_user**
> models::User activate_user(ctx, )
Activate a user

Activate user

### Required Parameters
This endpoint does not need any parameter.

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deactivate_user**
> models::User deactivate_user(ctx, )
Deactive user

Deactivate user

### Required Parameters
This endpoint does not need any parameter.

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update-password**
> models::User update-password(ctx, inline_object)
update password

Update user password

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object** | [**InlineObject**](InlineObject.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
